/* 极光推送 */
(function (window) {
	'use strict';
	var ajpush = null;
	var ajfunc = {
		// 极光推送服务监听
		ajPush_init: function (userId) {
			if (!userId) {
				api.toast({msg: '用户ID无效，无法启动推送服务'});
				return;
			}
			ajpush = api.require('ajpush');
			if (ajpush) {
				ajpush.isPushStopped(function (ret) {
          if (ret && ret.isStopped) {
						//恢复服务
						ajpush.resumePush(function (ret) {
							if (ret && ret.status) {
								//success
								// api.toast({msg: '极光推送恢复成功！'});
								ajfunc.init(userId);
							} else {
								api.toast({msg: '极光推送恢复失败！'});
							}
						});
					} else {
						// api.toast({msg: '服务正在运行'});
						ajfunc.init(userId);
					}
				});
			}
		},
		//初始化
		init: function (userId) {
			if(ajpush) {
				if (api.systemType == "android") {
					ajpush.init(function (ret) {
            if (ret && ret.status) {
							ajfunc.bindAliasAndTags(userId);
						}
					});
				}
				//IOS机制
				else if (api.systemType == "ios") {
					ajfunc.bindAliasAndTags(userId);
				}
			}
		},
		// 清除消息数
		ajpush_clear: function () {
			if (ajpush) {
				ajpush.setBadge({
					badge: 0
				});

				ajpush.clearNotification({
					id: -1
				}, function (ret) {
					if (ret && ret.status) {
						//success
					}
				});
			}
		},
		ajpush_exit: function () {
			if (ajpush) {
				//查询服务端的推送服务是否停止
				// ajpush.isPushStopped(function (ret) {
				// 	if (ret && !ret.isStopped) {
				// 		ajpush.stopPush(function (ret) {
				// 			if (ret && ret.status) {
				// 				//success
				// 				// api.toast({msg: '推送服务已停止'})
				// 			}
				// 		});
				// 	}
				// });
				if (api.systemType == "android") {
					ajpush.init(function (ret) {
						if (ret && ret.status) {
							ajfunc.rmBindAlias()
						}
					});
				} else if (api.systemType == "ios") {
					ajfunc.rmBindAlias()
				}
			}
		},
		//清除服务端的别名绑定
		rmBindAlias: function () {
			if (ajpush) {
				ajpush.bindAliasAndTags({
					alias: 'moon',
					tags: []
				}, function (ret) {
					var statusCode = ret.statusCode;
					// api.toast({msg: "绑定moon别名成功。极光推送返回的状态码："+statusCode});
					// 清除通知的count
					ajfunc.ajpush_clear();
					ajpush.removeListener();
				});
			}
		},
		//绑定用户别名和标签
		bindAliasAndTags: function (userId) {
			if (ajpush) {
				ajpush.bindAliasAndTags({
					alias: userId
				}, function (ret) {
          var statusCode = ret.statusCode;
					// api.toast({msg: "绑定" + userId + "别名成功。极光推送返回的状态码：" + statusCode});
					ajfunc.setListener(userId);
				});
			}
		},
		//设置消息监听，若iOS应用在前台运行，此时收到推送后也通过此方法回调
		setListener: function (userId) {
			if (ajpush) {
				ajpush.setListener(function (ret) {
					//消息接受\语音播报\振动(ios无效)开关
					var msg = ajfunc.getPrefs(userId + 'msg');
					var voice = ajfunc.getPrefs(userId + 'voice');
					var vibrate = ajfunc.getPrefs(userId + 'vibrate');

					//接受消息
					if (ret && msg) {
						// api.alert({msg: ret});
						var notify = {
							content: ret.content,
							title: ret.title,
							extra: ret.extra
						};
						var vibrates = vibrate ? [500, 500] : [0];
						//把自定义消息推送到通知栏
						ajfunc.pushNotifica(notify, vibrates);

						//把消息语音播放出来
						if (voice && ret.content) ajfunc.msgRead(ret.content);
					}
				});

			}
		},
		//科大讯飞语音播报
		msgRead: function (text) {
			var Speech = api.require('speechRecognizer');

			if (Speech) {
				Speech.read({
					readStr: text,
					speed: 60,
					volume: 100,
					voice: 'vixy',
					rate: 16000
				}, function (ret, err) {
					if (err) api.alert({msg: err.msg});
				});
			}
		},
		//获取偏好设置
		getPrefs: function (key) {
			var Pref = api.getPrefs({
				sync: true,
				key: key
			});

			return Pref == 'true';
		},
		//消息推送到通知栏
		pushNotifica: function (notify, vibrates) {
			if (api) {
				api.notification({
					notify: notify,
					vibrate: vibrates
				}, function (ret, err) {
					if (ret) {
						var id = ret.id;
					} else {
						api.alert({msg: err.msg});
					}
				});
			}
		},
		//查看注册用户id
		getRegister: function () {
			if (ajpush) {
				ajpush.getRegistrationId(function (ret) {
					if (ret) {
						var registrationId = ret.id;
					}
					api.toast({
						msg: 'registrationId:' + registrationId
					});
				});
			}
		}
	};

	window.ajfunc = ajfunc;

})(window);
